@@ -30,7 +30,7 @@ import hypothesis.internal.conjecture.utils as cu
 from hypothesis.errors import InvalidArgument
 from hypothesis.control import reject
 from hypothesis.internal.compat import hrange
-from hypothesis.internal.branchcheck import check, check_function
+from hypothesis.internal.coverage import check, check_function
 
 try:
     from pandas.api.types import is_categorical_dtype
@@ -400,7 +400,7 @@ def data_frames(
 
     .. code-block:: pycon
 
-        >>> from hypothesis.extra.pandas import column, data_frames
+        >>> from hypothesis.extra.pandas import columns, data_frames
         >>> import hypothesis.strategies as st
         >>> data_frames(
         ...     columns=columns(["lo", "hi"], dtype=float),
@@ -526,7 +526,7 @@ def data_frames(
 
             # For columns with no filling the problem is harder, and drawing
             # them like that would result in rows being very far apart from
-            # eachother in the underlying data stream, which gets in the way
+            # each other in the underlying data stream, which gets in the way
             # of shrinking. So what we do is reorder and draw those columns
             # row wise, so that the values of each row are next to each other.
             # This makes life easier for the shrinker when deleting blocks of
